# Always prefer setuptools over distutils
from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open
from os import path

# The directory containing this file
HERE = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(HERE, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

# This call to setup() does all the work.
setup(
    name="botbuilder-discord",
    version="0.1.0",
    description="Unofficial Discord.py connector for Microsoft's Bot Framework",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://botbuilder-discord.readthedocs.io/",
    author="Joffrey Bienvenu",
    author_email="joffreybvn@gmail.com",
    license="MIT",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Operating System :: OS Independent",
        "Topic :: Utilities"
    ],
    packages=find_packages(include=["botbuilder_discord", "botbuilder_discord.*"]),
    include_package_data=True,
    install_requires=["aiohttp", "Flask"]
)
